import {Color} from "./Core/Color";
export interface Assembly {
    name: string;
    data: Uint8Array | string;
}
export interface BootData {
    wasm: Uint8Array | string;
    assemblies: Assembly[];
    entryAssemblyName: string;
}
export declare enum BootStatus {
    Standby = "Standby",
    Booting = "Booting",
    Terminating = "Terminating",
    Booted = "Booted"
}
export declare function getBootStatus(): BootStatus;
export declare function boot(): Promise<void>;
export declare function terminate(): Promise<void>;
export declare class Event<T extends any[]> implements EventBroadcaster<T>, EventSubscriber<T> {
    private readonly handlers;
    private readonly warn;
    private lastArgs;
    constructor(warn?: ((message: string) => void) | null);
    broadcast(...args: [...T]): void;
    subscribe(handler: (...args: [...T]) => void): string;
    unsubscribe(handler: (...args: [...T]) => void): void;
    subscribeById(id: string, handler: (...args: [...T]) => void): void;
    unsubscribeById(id: string): void;
    getLast(): T | undefined;
    private getOrDefineId;
}
export interface EventBroadcaster<T extends any[]> {
    broadcast: (...args: [...T]) => void;
}
export interface EventSubscriber<T extends any[]> {
    subscribe: (handler: (...args: [...T]) => void) => string;
    unsubscribe: (handler: (...args: [...T]) => void) => void;
    getLast: () => T | undefined;
}
export declare const invoke: <T>(assembly: string, method: string, ...args: any[]) => T;
export declare const invokeAsync: <T>(assembly: string, method: string, ...args: any[]) => Promise<T>;
export declare const createObjectReference: (object: any) => any;
export declare const disposeObjectReference: (objectReference: any) => void;
export declare const createStreamReference: (buffer: Uint8Array | any) => any;
export namespace Aspose.CAD {
    export enum FileFormat {
        Undefined,
        Custom,
        Bmp,
        Gif,
        Jpeg,
        Png,
        Tiff,
        Psd,
        Jpeg2000,
        Djvu,
        Webp,
        Emf,
        Dicom,
        Svg,
        Wmf,
        Dng,
        Pdf,
        CadR9,
        CadR010,
        CadR011,
        CadR012,
        CadR013,
        CadR014,
        CadR015,
        CadR021,
        CadR0221,
        CadR0222,
        CadR025,
        CadR026,
        CadR2000,
        CadR2004,
        CadR2007,
        CadR2010,
        CadR2013,
        CadR2018,
        DgnV7,
        DgnV8,
        DgnV9,
        DXFCadR010,
        DXFCadR012,
        DXFCadR014,
        DXFCadR015,
        DXFCadR021,
        DXFCadR0221,
        DXFCadR0222,
        DXFCadR025,
        DXFCadR026,
        DXFCadR9,
        DXFCadR10,
        DXFCadR11,
        DXFCadR13,
        DXFCadR14,
        DXFCadR2000,
        DXFCadR2004,
        DXFCadR2007,
        DXFCadR2010,
        DXFCadR2013,
        IFC2X3,
        STL,
        Dwf,
        IGES,
        Plt,
        DwtCadR010,
        DwtCadR012,
        DwtCadR014,
        DwtCadR015,
        DwtCadR021,
        DwtCadR0221,
        DwtCadR0222,
        DwtCadR025,
        DwtCadR026,
        DwtCadR9,
        DwtCadR10,
        DwtCadR11,
        DwtCadR13,
        DwtCadR14,
        DwtCadR2000,
        DwtCadR2004,
        DwtCadR2007,
        DwtCadR2010,
        DwtCadR2013,
        CF2,
        OBJ,
        IFC4,
        FBX,
        Dwfx,
        Collada,
        DXB,
        STP,
        ThreeDS,
        Odg,
        Eps,
        Cdr,
        Cmx,
        Otg,
        Html5Canvas,
        Apng,
        Tga,
        Emz,
        Wmz,
        Svgz,
        FOdg
    }
}
export namespace Aspose.CAD.Wasm {
    export function environment(): any;
    export function culture(): any;
    export function getFileFormat(file: Uint8Array): Aspose.CAD.FileFormat;
    export function load(file: Uint8Array): Uint8Array;
    export function save(data: Uint8Array, options: any): Promise<Uint8Array>;
}
